Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/crypto/dist/ipsec-tools/src From Stefan Bauer: Fix multiple ...



details:   https://anonhg.NetBSD.org/src/rev/3a7e4c146eae
branches:  trunk
changeset: 752730:3a7e4c146eae
user:      tteras <tteras%NetBSD.org@localhost>
date:      Fri Mar 05 06:47:58 2010 +0000

description:
>From Stefan Bauer: Fix multiple typoes and manpage formatting errors.

diffstat:

 crypto/dist/ipsec-tools/src/libipsec/ipsec_set_policy.3 |   4 +-
 crypto/dist/ipsec-tools/src/racoon/doc/FAQ              |   2 +-
 crypto/dist/ipsec-tools/src/racoon/privsep.c            |   6 +-
 crypto/dist/ipsec-tools/src/setkey/setkey.8             |  26 ++++++++--------
 4 files changed, 19 insertions(+), 19 deletions(-)

diffs (119 lines):

diff -r d34e26f4e7ee -r 3a7e4c146eae crypto/dist/ipsec-tools/src/libipsec/ipsec_set_policy.3
--- a/crypto/dist/ipsec-tools/src/libipsec/ipsec_set_policy.3   Fri Mar 05 02:21:41 2010 +0000
+++ b/crypto/dist/ipsec-tools/src/libipsec/ipsec_set_policy.3   Fri Mar 05 06:47:58 2010 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: ipsec_set_policy.3,v 1.14 2009/10/14 23:36:55 joerg Exp $
+.\"    $NetBSD: ipsec_set_policy.3,v 1.15 2010/03/05 06:47:58 tteras Exp $
 .\"
 .\"    $KAME: ipsec_set_policy.3,v 1.16 2003/01/06 21:59:03 sumikawa Exp $
 .\"
@@ -126,7 +126,7 @@
 .Bl -tag  -width "discard"
 .It Ar {priority,prio} offset
 .Ar offset
-is an integer in the range -2147483647..214783648.
+is an integer in the range \-2147483647..214783648.
 .It Ar {priority,prio} base {+,-} offset
 .Ar base
 is either
diff -r d34e26f4e7ee -r 3a7e4c146eae crypto/dist/ipsec-tools/src/racoon/doc/FAQ
--- a/crypto/dist/ipsec-tools/src/racoon/doc/FAQ        Fri Mar 05 02:21:41 2010 +0000
+++ b/crypto/dist/ipsec-tools/src/racoon/doc/FAQ        Fri Mar 05 06:47:58 2010 +0000
@@ -18,7 +18,7 @@
 
 A:
        Configure both ends exactly the same.  With just a tiny little
-       differnce, you will be in trouble.
+       difference, you will be in trouble.
 
 Q: How to build racoon on my platform?
 
diff -r d34e26f4e7ee -r 3a7e4c146eae crypto/dist/ipsec-tools/src/setkey/setkey.8
--- a/crypto/dist/ipsec-tools/src/setkey/setkey.8       Fri Mar 05 02:21:41 2010 +0000
+++ b/crypto/dist/ipsec-tools/src/setkey/setkey.8       Fri Mar 05 06:47:58 2010 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: setkey.8,v 1.22 2010/01/15 19:18:51 joerg Exp $
+.\"    $NetBSD: setkey.8,v 1.23 2010/03/05 06:47:58 tteras Exp $
 .\"
 .\" Copyright (C) 1995, 1996, 1997, 1998, and 1999 WIDE Project.
 .\" All rights reserved.
@@ -625,7 +625,7 @@
 addresses to get the correct matching.
 Here is an example:
 .Bd -literal -offset
-spdadd 10.0.11.0/24[any] 10.0.11.33/32[any] any -P out ipsec
+spdadd 10.0.11.0/24[any] 10.0.11.33/32[any] any \-P out ipsec
     esp/tunnel/192.168.0.1[4500]-192.168.1.2[30000]/require ;
 
 .Ed
@@ -761,14 +761,14 @@
 .Sh EXAMPLES
 .Bd -literal -offset
 add 3ffe:501:4819::1 3ffe:501:481d::1 esp 123457
-       -E des-cbc 0x3ffe05014819ffff ;
+       \-E des-cbc 0x3ffe05014819ffff ;
 
-add -6 myhost.example.com yourhost.example.com ah 123456
-       -A hmac-sha1 "AH SA configuration!" ;
+add \-6 myhost.example.com yourhost.example.com ah 123456
+       \-A hmac-sha1 "AH SA configuration!" ;
 
 add 10.0.11.41 10.0.11.33 esp 0x10001
-       -E des-cbc 0x3ffe05014819ffff
-       -A hmac-md5 "authentication!!" ;
+       \-E des-cbc 0x3ffe05014819ffff
+       \-A hmac-md5 "authentication!!" ;
 
 get 3ffe:501:4819::1 3ffe:501:481d::1 ah 123456 ;
 
@@ -777,17 +777,17 @@
 dump esp ;
 
 spdadd 10.0.11.41/32[21] 10.0.11.33/32[any] any
-       -P out ipsec esp/tunnel/192.168.0.1-192.168.1.2/require ;
+       \-P out ipsec esp/tunnel/192.168.0.1-192.168.1.2/require ;
 
-add 10.1.10.34 10.1.10.36 tcp 0x1000 -A tcp-md5 "TCP-MD5 BGP secret" ;
+add 10.1.10.34 10.1.10.36 tcp 0x1000 \-A tcp-md5 "TCP-MD5 BGP secret" ;
 
 add 10.0.11.41 10.0.11.33 esp 0x10001
-       -ctx 1 1 "system_u:system_r:unconfined_t:SystemLow-SystemHigh"
-       -E des-cbc 0x3ffe05014819ffff;
+       \-ctx 1 1 "system_u:system_r:unconfined_t:SystemLow-SystemHigh"
+       \-E des-cbc 0x3ffe05014819ffff;
 
 spdadd 10.0.11.41 10.0.11.33 any
-       -ctx 1 1 "system_u:system_r:unconfined_t:SystemLow-SystemHigh"
-       -P out ipsec esp/transport//require ;
+       \-ctx 1 1 "system_u:system_r:unconfined_t:SystemLow-SystemHigh"
+       \-P out ipsec esp/transport//require ;
 .Ed
 .\"
 .Sh SEE ALSO



Home | Main Index | Thread Index | Old Index
diff -r d34e26f4e7ee -r 3a7e4c146eae crypto/dist/ipsec-tools/src/racoon/privsep.c
--- a/crypto/dist/ipsec-tools/src/racoon/privsep.c      Fri Mar 05 02:21:41 2010 +0000
+++ b/crypto/dist/ipsec-tools/src/racoon/privsep.c      Fri Mar 05 06:47:58 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: privsep.c,v 1.19 2008/12/23 14:03:12 tteras Exp $      */
+/*     $NetBSD: privsep.c,v 1.20 2010/03/05 06:47:58 tteras Exp $      */
 
 /* Id: privsep.c,v 1.15 2005/08/08 11:23:44 vanhu Exp */
 
@@ -1465,7 +1465,7 @@
 }
 
 /*
  * Filter unsafe environement variables
  */
 static int
 unsafe_env(envp)
@@ -1486,7 +1486,7 @@
        return 0;
 found:
        plog(LLV_ERROR, LOCATION, NULL, 
-           "privsep_script_exec: unsafe environement variable\n");
+           "privsep_script_exec: unsafe environment variable\n");
        return -1;
 }
 
@@ -1465,7 +1465,7 @@
 
 /*
- * Filter unsafe environement variables
+ * Filter unsafe environment variables
  */
 static int